.. _sourcecode-section:

Source Code Documentation
=========================

Documentation for the primary SMCPy classes.

SMC Module Documentation
------------------------

.. automodule:: smcpy.smc.smc_sampler
.. autoclass:: SMCSampler
    :members:
.. automodule:: smcpy.smc.smc_step
.. autoclass:: SMCStep
    :members:
.. automodule:: smcpy.smc.particle_initializer
.. autoclass:: ParticleInitializer
    :members:
.. automodule:: smcpy.smc.particle_updater
.. autoclass:: ParticleUpdater
    :members:
.. automodule:: smcpy.smc.particle_mutator
.. autoclass:: ParticleMutator
    :members:

Particle Module Documentation
------------------------------

.. automodule:: smcpy.particles.particle
.. autoclass:: Particle
    :members:

MCMC Module Documentation
--------------------------

.. automodule:: smcpy.mcmc.mcmc_sampler
.. autoclass:: MCMCSampler
    :members:

HDF5 Module Documentation
--------------------------

.. automodule:: smcpy.hdf5.hdf5_storage
.. autoclass:: HDF5Storage
    :members:

